@@ -45,7 +45,7 @@ from docutils.parsers.rst.directives import flag, unchanged, nonnegative_int
 
 from sphinx.util import logging as sphinx_logging
 
-__version__ = '0.17.4'
+__version__ = '0.17.7'
 
 logger = sphinx_logging.getLogger('contrib.commandoutput')
 
@@ -67,7 +67,8 @@ class CommandOutputDirective(rst.Directive):
 
     option_spec = dict(shell=flag, prompt=flag, nostderr=flag,
                        ellipsis=_slice, extraargs=unchanged,
-                       returncode=nonnegative_int, cwd=unchanged)
+                       returncode=nonnegative_int, cwd=unchanged,
+                       caption=unchanged)
 
     def run(self):
         env = self.state.document.settings.env
@@ -100,7 +101,7 @@ class Command(_Command):
     """
 
     def __new__(cls, command, shell=False, hide_standard_error=False,
-                working_directory='/'):
+                working_directory='/', caption=''):
         if isinstance(command, list):
             command = tuple(command)
         # `chdir()` resolves symlinks, so we need to resolve them too for
@@ -110,7 +111,7 @@ class Command(_Command):
         working_directory = os.path.normpath(os.path.realpath(
             working_directory))
         return _Command.__new__(cls, command, shell, hide_standard_error,
-                                working_directory)
+                                working_directory, caption)
 
     @classmethod
     def from_command_output_node(cls, node):
@@ -209,7 +210,7 @@ def container_wrapper(directive, literal_node, caption: str):  # NOQA
     container_node = nodes.container('', literal_block=True,
                                      classes=['literal-block-wrapper'])
     parsed = nodes.Element()
-    directive.state.nested_parse(StringList([caption], source=''),
+    directive.state.nested_parse([caption],
                                  directive.content_offset, parsed)
     if isinstance(parsed[0], nodes.system_message):
         msg = __('Invalid caption: %s' % parsed[0].astext())
